@@ -33,15 +33,12 @@ class SPI:
         self.chip = detector.chip
 
     def set_no_cs(self):
-        # Linux SPI driver for AM33XX chip in BeagleBone and PocketBeagle
-        # does not support setting SPI_NO_CS mode bit (issue #104)
-        if not self.chip.AM33XX and not self.chip.IMX8MX and not self.chip.SAMA5 \
-         and not self.chip.APQ8016 and not self.chip.T210 and not self.chip.T186 \
-         and not self.chip.T194 and not self.chip.SUN8I:
-            try:
-                self._spi.no_cs = True  # this doesn't work but try anyways
-            except AttributeError:
-                pass
+        # No kernel seems to support this, so we're just going to pass
+        pass
+
+    @property
+    def frequency(self):
+        return self.baudrate
 
     def write(self, buf, start=0, end=None):
         if not buf:
